@@ -13,7 +13,7 @@ class String:
             return False
         if self.regex:
             if isinstance(self.regex, str) and not re.fullmatch(
-                    self.regex, str(other), self.flags()
+                self.regex, str(other), self.flags()
             ):
                 return False
             if isinstance(self.regex, re.Pattern) and not self.regex.fullmatch(other):
@@ -25,3 +25,8 @@ class String:
         if self.ignore_case:
             flags |= re.IGNORECASE
         return flags
+
+
+UUID = String(
+    regex=re.compile("[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89aAbB][a-f0-9]{3}-[a-f0-9]{12}")
+)
